@@ -14,9 +14,6 @@ class dict_to_obj(object):
     def __str__(self):
         return "dict_to_obj_format"
 
-def dict_to_json(dicts):
-    return json.dumps(dicts)
-
 
 def obj_to_dict(obj):
     out = vars(obj)
